import request from '@/utils/request'

// 查询泄漏点列表
export function listPoint(query) {
  return request({
    url: '/car/point/list',
    method: 'get',
    params: query
  })
}

// 查询泄漏点详细
export function getPoint(id) {
  return request({
    url: '/car/point/' + id,
    method: 'get'
  })
}

// 新增泄漏点
export function addPoint(data) {
  return request({
    url: '/car/point',
    method: 'post',
    data: data
  })
}

// 修改泄漏点
export function updatePoint(data) {
  return request({
    url: '/car/point',
    method: 'put',
    data: data
  })
}

// 删除泄漏点
export function delPoint(id) {
  return request({
    url: '/car/point/' + id,
    method: 'delete'
  })
}

// 导出泄漏点
export function exportPoint(query) {
  return request({
    url: '/car/point/export',
    method: 'get',
    params: query
  })
}

export function pointInfoList(query) {
  return request({
    url: '/car/point/pointInfoList',
    method: 'get',
    params: query
  })
}
